@@ -6,6 +6,7 @@ from twisted.internet import reactor
 from twisted.internet.defer import Deferred, DeferredList
 
 from pagegetter import RequestQueuer, PageGetter
+from unicodeconverter import convertToUTF8
 
 from aws import AmazonS3, AmazonSDB
 
@@ -58,7 +59,7 @@ def evaluateBoolean( b ):
         except:
             return False
 
-class Spider:
+class AWSpider:
 
     """
     Amazon S3, Amazon EC2 based web spider.
@@ -180,13 +181,13 @@ class Spider:
         filtered_kwargs = {}
         for key in function["required_arguments"]:
             if key in kwargs:
-                filtered_kwargs[key] = unicode( kwargs[key] ).encode("utf-8")
+                filtered_kwargs[key] = convertToUTF8( kwargs[key] )
             else:
                 raise Exception("Required parameter '%s' not found. Required parameters are %s. Optional parameters are %s." % (key, function["required_arguments"], function["optional_arguments"] ))
 
         for key in function["optional_arguments"]:
             if key in kwargs:
-                filtered_kwargs[key] = unicode( kwargs[key] ).encode("utf-8")
+                filtered_kwargs[key] = convertToUTF8( kwargs[key] )
         
         if function["interval"] > 0:
             reserved_arguments = {}
@@ -278,7 +279,7 @@ class Spider:
     def expose( self, *args, **kwargs ):
         return self.makeCallable( expose=True, *args, **kwargs )
         
-    def makeCallable( self, func, interval=60*60, name=None, expose=False ):
+    def makeCallable( self, func, interval=0, name=None, expose=False ):
             
         argspec = inspect.getargspec( func )
         arguments = argspec[0]
