@@ -1,6 +1,6 @@
 from twisted.internet import reactor
 from twisted.internet import defer
-from twisted.web.client import getPage, HTTPClientFactory, HTTPDownloader, _parse
+from twisted.web.client import HTTPClientFactory, HTTPDownloader, _parse
 from unicodeconverter import convertToUTF8, convertToUnicode
 import cPickle
 import sha
@@ -8,9 +8,10 @@ import time
 import dateutil.parser
 import datetime
 import pytz
+import urllib
 
 import logging
-logger = logging.getLogger("jasper")
+logger = logging.getLogger("main")
 
 class RequestQueuer():
 
@@ -101,7 +102,7 @@ class RequestQueuer():
             headers = {}
 
         scheme, host, port, path = _parse(url)
-        
+
         factory = HTTPClientFactory(
             url, 
             method=method, 
@@ -159,8 +160,19 @@ class PageGetter:
 
         if metadata is None:
             metadata = {}
-
-        if method != "GET":
+        
+        if isinstance( postdata, dict ):
+            for key in postdata:
+                postdata[key] = convertToUTF8( postdata[key] )
+            postdata = urllib.urlencode( postdata )
+        
+        if method.lower() == "post":
+            if headers is None:
+                headers = {"content-type":"application/x-www-form-urlencoded"}
+            else:
+                headers["content-type"] = "application/x-www-form-urlencoded"
+                
+        if method.lower() != "get":
             d = self.rq.getPage( url, method=method, postdata=postdata, headers=headers, agent=agent, timeout=timeout, cookies=cookies, followRedirect=followRedirect, prioritize=prioritize )
             return d       
         
